#ifndef SETTINGSDLG_H
#define SETTINGSDLG_H

#include <QtGui/QDialog>
#include "ui_settingsdlg.h"

class Settings;

class SettingsDlg : public QDialog
{
    Q_OBJECT;

public:
    SettingsDlg( QWidget *parent = 0 );
    ~SettingsDlg();

private slots:

    void addFolderButtonClicked();
    void removeFolderButtonClicked();
    void cellClicked();
    void zoomEnabled( bool enabled );
    void frameDropEnabled( bool enabled );

private:
    void setupFolderList();

private:
    Ui::SettingsDlgClass ui;
};

#endif // SETTINGSDLG_H
